pub mod basic_matrix;
pub mod extended_matrix;
pub mod shape;
pub mod matrix_element_position;
pub mod functions;
